Installation
============

To install the package from PyPi, you can use `pip`. Follow the steps below:

1. Installation using pip:

.. code-block:: console

    pip install xpcs-correlator

2. Verify the installation:

.. code-block:: console

    python -c "import xpcscorr"

